netapp_ontap.models.dcn_node_statistics_gpu API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_node_statistics_gpu`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnNodeStatisticsGpuSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnNodeStatisticsGpu object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `memory_used: Size GET POST PATCH`

    Current memory usage on the node, in bytes.

    Example: 1024000000

  `processor_utilization_base: Size GET POST PATCH`

    Base counter for GPU utilization.

    Example: 35042835393

  `processor_utilization_raw: Size GET POST PATCH`

    Raw GPU utilization for the node. Divide this by the processor_utilization_base to calculate the percentage GPU utilization for the node.

    Example: 2514992973